@@ -1,7 +1,7 @@
-from .repair import repair, repair_extracted, resolve_sharedlib
+from .repair import copylib, repair, repair_extracted, resolve_sharedlib
 from .show import show, show_dylib, show_wheel
 
-__version__ = "0.0.2"
+__version__ = "0.0.5"
 __all__ = [
     "repair",
     "repair_extracted",
@@ -9,4 +9,5 @@ __all__ = [
     "show",
     "show_wheel",
     "show_dylib",
+    "copylib",
 ]
